@@ -7,79 +7,69 @@ package Sub::HandlesVia;
 use Exporter::Shiny qw( delegations );
 
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = '0.008_003';
+our $VERSION   = '0.001';
 
-sub _generate_delegations {
-	my ($me, $name, $args, $globals) = (shift, @_);
-	
-	my $target = $globals->{into};
-	!defined $target and die;
-	ref $target and die;
-
-	my $toolkit = $me->detect_toolkit($target);
-	return sub { $toolkit->install_delegations(target => $target, @_) };
-}
-
-sub _exporter_validate_opts {
-	my ($me, $globals) = (shift, @_);
-
-	my $target = $globals->{into};
-	!defined $target and die;
-	ref $target and die;
-
-	my $toolkit = $me->detect_toolkit($target);
-	$toolkit->setup_for($target) if $toolkit->can('setup_for');
-}
-
-sub detect_toolkit {
-	my $toolkit = sprintf(
-		'%s::Toolkit::%s',
-		__PACKAGE__,
-		shift->_detect_framework(@_),
-	);
-	eval "require $toolkit" or Exporter::Tiny::_croak($@);
-	return $toolkit;
-}
-
-sub _detect_framework {
-	my ($me, $target) = (shift, @_);
+sub import {
+	my $me     = shift;
+	my $target = caller;
 	
 	if ($INC{'Moo/Role.pm'}
 	and Moo::Role->is_role($target)) {
-		return 'Moo';
+		require Sub::HandlesVia::Toolkit::Moo;
+		Sub::HandlesVia::Toolkit::Moo->setup_for($target);
 	}
 	
-	if ($INC{'Moo.pm'}
+	elsif ($INC{'Moo.pm'}
 	and $Moo::MAKERS{$target}
 	and $Moo::MAKERS{$target}{is_class}) {
-		return 'Moo';
+		require Sub::HandlesVia::Toolkit::Moo;
+		Sub::HandlesVia::Toolkit::Moo->setup_for($target);
 	}
 	
-	if ($INC{'Moose/Role.pm'}
+	elsif ($INC{'Moose/Role.pm'}
 	and $target->can('meta')
 	and $target->meta->isa('Moose::Meta::Role')) {
-		return 'Moose';
+		require Sub::HandlesVia::Toolkit::Moose;
+		Sub::HandlesVia::Toolkit::Moose->setup_for($target);
 	}
 	
-	if ($INC{'Moose.pm'}
+	elsif ($INC{'Moose.pm'}
 	and $target->can('meta')
 	and $target->meta->isa('Moose::Meta::Class')) {
-		return 'Moose';
+		require Sub::HandlesVia::Toolkit::Moose;
+		Sub::HandlesVia::Toolkit::Moose->setup_for($target);
 	}
 
-	if ($INC{'Mouse/Role.pm'}
+	elsif ($INC{'Mouse/Role.pm'}
 	and $target->can('meta')
 	and $target->meta->isa('Mouse::Meta::Role')) {
-		return 'Mouse';
+		require Sub::HandlesVia::Toolkit::Mouse;
+		Sub::HandlesVia::Toolkit::Mouse->setup_for($target);
 	}
 	
-	if ($INC{'Mouse.pm'}
+	elsif ($INC{'Mouse.pm'}
 	and $target->can('meta')
 	and $target->meta->isa('Mouse::Meta::Class')) {
-		return 'Mouse';
+		require Sub::HandlesVia::Toolkit::Mouse;
+		Sub::HandlesVia::Toolkit::Mouse->setup_for($target);
 	}
 	
-	return 'Plain';
+	if (@_) {
+		unshift @_, $me;
+		goto \&Exporter::Tiny::import;
+	}
+}
+
+sub _generate_delegations {
+	my $me = shift;
+	my ($name, $args, $globals) = @_;
+	
+	my $target = $globals->{into};
+	!defined $target and die;
+	ref $target and die;
+	
+	require Sub::HandlesVia::Toolkit::Plain;
+	sub { Sub::HandlesVia::Toolkit::Plain->delegations(target => $target, @_) };
 }
 
 1;
@@ -128,7 +118,7 @@ before, you should have a fairly good idea what this does.
 
 Why re-invent the wheel? Well, this is an implementation that should work
 okay with Moo, Moose, Mouse, and any other OO toolkit you throw at it.
-One ring to rule them all, so to speak.
+One ring to rule them all, so to speak. (Moose support is a TODO though!)
 
 Also, unlike L<MooX::HandlesVia>, it honours type constraints, plus it
 doesn't have the limitation that it can't mutate non-reference values.
@@ -336,11 +326,6 @@ the setter is also passed a value to set.
 Really, I don't think there's any object system that this won't work
 for!
 
-(The C<delegations> function can be imported into Moo/Mouse/Moose classes
-too, in which case the C<attribute> needs to be the same attribute name
-you passed to C<has>. You cannot use a arrayref, coderef, hash key, or
-array index.)
-
 =head2 What methods can be delegated to?
 
 The following table compares Sub::HandlesVia with L<Data::Perl>, L<Moose>
@@ -366,7 +351,6 @@ aliases for existing methods.
        for_each_pair :                      Mouse
                  get : SubHV  DataP  Moose  Mouse
                 grep : SubHV  DataP  Moose  Mouse
-                head : SubHV  DataP              
               insert : SubHV  DataP  Moose  Mouse
             is_empty : SubHV  DataP  Moose  Mouse
                 join : SubHV  DataP  Moose  Mouse
@@ -389,7 +373,6 @@ aliases for existing methods.
     sort_in_place_by :                      Mouse
               splice : SubHV  DataP  Moose  Mouse
                store :                      Mouse
-                tail : SubHV  DataP              
                 uniq : SubHV  DataP  Moose  Mouse
        uniq_in_place : SubHV                     
              unshift : SubHV  DataP  Moose  Mouse
@@ -444,9 +427,6 @@ aliases for existing methods.
                  set : SubHV         Moose       
                  sub : SubHV  DataP  Moose  Mouse
 
-  Scalar ==========================================
-    scalar_reference : SubHV                    
-
   String ==========================================
               append : SubHV  DataP  Moose  Mouse
                chomp : SubHV  DataP  Moose  Mouse
@@ -529,7 +509,7 @@ encapsulation of course):
 
 And C<< $kitchen->find_healthiest_food >> does this:
 
-  $kitchen->food->find_healthiest
+  C<< $kitchen->food->find_healthiest >>
 
 Basically, because C<find_healthiest> isn't one of the methods offered
 by Sub::HandlesVia::HandlerList::Array, it assumes you want to call it
