@@ -5,7 +5,7 @@ use warnings;
 package Sub::HandlesVia::Handler;
 
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = '0.008_003';
+our $VERSION   = '0.001';
 
 use Class::Tiny (
 	qw(
@@ -181,7 +181,6 @@ sub _process_template {
 	$template =~ s/\$ARG\[([0-9]+)\]/$callbacks{arg}->($1)/eg;
 	$template =~ s/\$ARG/$callbacks{arg}->(1)/eg;
 	$template =~ s/\$SELF/$callbacks{self}->()/eg;
-	$template =~ s/\$SLOT/$callbacks{slot}->()/eg;
 	$template =~ s/\#ARG/$callbacks{argc}->()/eg;
 	$template =~ s/\@ARG/$callbacks{args}->()/eg;
 	$template =~ s/«(.+?)»/$callbacks{set}->($1)/eg;
@@ -198,8 +197,6 @@ sub _coderef {
 	
 	my @code = ('sub {');
 	
-	push @code, sprintf('package %s::__SANDBOX__;', __PACKAGE__);
-	
 	my $sig_was_checked = 0;
 	if (@{ $self->signature || [] }) {
 		require Type::Params;
@@ -337,21 +334,21 @@ sub install_method {
 	
 	if ( eval { require Sub::Util }) {
 		$coderef = Sub::Util::set_subname("$target\::$name", $coderef);
+		no strict 'refs';
+		*{"$target\::$name"} = $coderef;
 	}
 	elsif ( eval { require Sub::Name }) {
 		$coderef = Sub::Name::subname("$target\::$name", $coderef);
-	}
-	
-	if ($callbacks{install_method}) {
-		$callbacks{install_method}->($name, $coderef);
-	}
-	elsif ($callbacks{install_method_fq}) {
-		$callbacks{install_method}->("$target\::$name", $coderef);
-	}
-	else {
 		no strict 'refs';
 		*{"$target\::$name"} = $coderef;
 	}
+	else {
+		eval qq{
+			package $target;
+			sub $name { goto \$coderef };
+			1;
+		} or die($@);
+	}
 }
 
 sub code_as_string {
@@ -384,7 +381,7 @@ sub _generate_handler {
 package Sub::HandlesVia::Handler::Traditional;
 
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = '0.008_003';
+our $VERSION   = '0.001';
 
 BEGIN { our @ISA = 'Sub::HandlesVia::Handler' };
 
@@ -396,8 +393,6 @@ sub _coderef {
 	my ($self, %callbacks) = @_;
 	
 	my @code = 'sub {';
-	push @code, sprintf('package %s::__SANDBOX__;', __PACKAGE__);
-	
 	my $env = {};
 	
 	if (my $curried = $self->curried) {
@@ -427,7 +422,7 @@ sub _coderef {
 package Sub::HandlesVia::Handler::CodeRef;
 
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = '0.008_003';
+our $VERSION   = '0.001';
 
 BEGIN { our @ISA = 'Sub::HandlesVia::Handler' };
 
@@ -441,8 +436,6 @@ sub _coderef {
 	my ($self, %callbacks) = @_;
 	
 	my @code = 'sub {';
-	push @code, sprintf('package %s::__SANDBOX__;', __PACKAGE__);
-	
 	my $env = { '$shv_callback' => \($self->delegated_coderef) };
 	
 	if (my $curried = $self->curried) {
