@@ -5,7 +5,7 @@ use warnings;
 package Sub::HandlesVia::HandlerLibrary::Array;
 
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = '0.008_003';
+our $VERSION   = '0.001';
 
 use Sub::HandlesVia::HandlerLibrary;
 our @ISA = 'Sub::HandlesVia::HandlerLibrary';
@@ -17,7 +17,7 @@ our @METHODS = qw( count is_empty all elements flatten get pop push shift
 	unshift clear first first_index reduce set accessor natatime
 	shallow_clone map grep sort reverse sort_in_place splice shuffle
 	shuffle_in_place uniq uniq_in_place delete insert flatten flatten_deep
-	join print head tail );
+	join print );
 
 sub _type_inspector {
 	my ($me, $type) = @_;
@@ -215,25 +215,13 @@ sub first {
 }
 
 sub first_index {
-	my $me = __PACKAGE__;
+	require List::MoreUtils;
 	handler
 		name      => 'Array:first_index',
 		args      => 1,
 		signature => [CodeRef],
 		usage     => '$coderef',
-		template  => $me.'::_firstidx($ARG, @{$GET})',
-}
-
-# Implementation from List::MoreUtils::PP.
-# Removed original prototype.
-sub _firstidx {
-	my $f = CORE::shift;
-	foreach my $i (0 .. $#_)
-	{
-		local *_ = \$_[$i];
-		return $i if $f->();
-	}
-	return -1;
+		template  => '&List::MoreUtils::first_index($ARG, @{$GET})',
 }
 
 sub reduce {
@@ -307,22 +295,14 @@ sub accessor {
 }
 
 sub natatime {
-	my $me = __PACKAGE__;
+	require List::MoreUtils;
 	handler
 		name      => 'Array:natatime',
 		min_args  => 1,
 		max_args  => 2,
 		signature => [Int, Optional[CodeRef]],
 		usage     => '$n, $callback?',
-		template  => 'my $shv_iterator = '.$me.'::_natatime($ARG[1], @{$GET}); if ($ARG[2]) { while (my @shv_values = $shv_iterator->()) { $ARG[2]->(@shv_values) } } else { $shv_iterator }',
-}
-
-# Implementation from List::MoreUtils::PP.
-# Removed original prototype.
-sub _natatime {
-	my $n    = CORE::shift;
-	my @list = @_;
-	return sub { CORE::splice @list, 0, $n }
+		template  => 'my $shv_iterator = &List::MoreUtils::natatime($ARG[1], @{$GET}); if ($ARG[2]) { while (my @shv_values = $shv_iterator->()) { $ARG[2]->(@shv_values) } } else { $shv_iterator }',
 }
 
 sub shallow_clone {
@@ -526,22 +506,4 @@ sub print {
 		template  => 'my $shv_param_with = (#ARG>1) ? $ARG[2] : q[,]; print {$ARG[1]||*STDOUT} join($shv_param_with, @{$GET})',
 }
 
-sub head {
-	handler
-		name      => 'Array:head',
-		args      => 1,
-		signature => [Int],
-		usage     => '$count',
-		template  => 'my $shv_count=$ARG; $shv_count=@{$GET} if $shv_count>@{$GET}; $shv_count=@{$GET}+$shv_count if $shv_count<0; (@{$GET})[0..($shv_count-1)]',
-}
-
-sub tail {
-	handler
-		name      => 'Array:tail',
-		args      => 1,
-		signature => [Int],
-		usage     => '$count',
-		template  => 'my $shv_count=$ARG; $shv_count=@{$GET} if $shv_count>@{$GET}; $shv_count=@{$GET}+$shv_count if $shv_count<0; my $shv_start = scalar(@{$GET})-$shv_count; my $shv_end = scalar(@{$GET})-1; (@{$GET})[$shv_start..$shv_end]',
-}
-
 1;
